@@ -239,8 +239,12 @@ class Vector2:
         Normalizes the vector so that the magnitude is equal to one while maintaining the same angle.
         """
         magnitude = self.magnitude()
-        self.x /= magnitude
-        self.y /= magnitude
+        if magnitude == 0:
+            self.x = 0
+            self.y = 0
+        else:
+            self.x /= magnitude
+            self.y /= magnitude
 
     def magnitude(
             self
@@ -257,9 +261,7 @@ class Vector2:
             self
     ) -> Vector2:
         vec2 = Vector2.from_vector2(self)
-        magnitude = self.magnitude()
-        vec2.x /= magnitude
-        vec2.y /= magnitude
+        vec2.normalize()
         return vec2
 
     def dot(
@@ -555,9 +557,14 @@ class Vector3:
         Normalizes the vector so that the magnitude is equal to one while maintaining the same angle.
         """
         magnitude = self.magnitude()
-        self.x /= magnitude
-        self.y /= magnitude
-        self.z /= magnitude
+        if magnitude == 0:
+            self.x = 0
+            self.y = 0
+            self.z = 0
+        else:
+            self.x /= magnitude
+            self.y /= magnitude
+            self.z /= magnitude
 
     def magnitude(
             self
@@ -574,10 +581,7 @@ class Vector3:
             self
     ) -> Vector3:
         vec3 = Vector3.from_vector3(self)
-        magnitude = self.magnitude()
-        vec3.x /= magnitude
-        vec3.y /= magnitude
-        vec3.z /= magnitude
+        vec3.normalize()
         return vec3
 
     def dot(
@@ -825,6 +829,24 @@ class Vector4:
 
         return Vector4(x, y, z, w)
 
+    @classmethod
+    def from_euler(
+            cls,
+            x: float,
+            y: float,
+            z: float
+    ):
+        roll = math.radians(x)
+        pitch = math.radians(y)
+        yaw = math.radians(z)
+
+        qx = math.sin(roll/2) * math.cos(pitch/2) * math.cos(yaw/2) - math.cos(roll/2) * math.sin(pitch/2) * math.sin(yaw/2)
+        qy = math.cos(roll/2) * math.sin(pitch/2) * math.cos(yaw/2) + math.sin(roll/2) * math.cos(pitch/2) * math.sin(yaw/2)
+        qz = math.cos(roll/2) * math.cos(pitch/2) * math.sin(yaw/2) - math.sin(roll/2) * math.sin(pitch/2) * math.cos(yaw/2)
+        qw = math.cos(roll/2) * math.cos(pitch/2) * math.cos(yaw/2) + math.sin(roll/2) * math.sin(pitch/2) * math.sin(yaw/2)
+
+        return Vector4(qx, qy, qz, qw)
+
     def magnitude(
             self
     ) -> float:
@@ -846,10 +868,16 @@ class Vector4:
             The same vector.
         """
         magnitude = self.magnitude()
-        self.x /= magnitude
-        self.y /= magnitude
-        self.z /= magnitude
-        self.w /= magnitude
+        if magnitude == 0:
+            self.x = 0
+            self.y = 0
+            self.z = 0
+            self.w = 0
+        else:
+            self.x /= magnitude
+            self.y /= magnitude
+            self.z /= magnitude
+            self.w /= magnitude
         return self
 
     def set(
@@ -958,6 +986,16 @@ class SurfaceMaterial(IntEnum):
     DEEP_WATER = 17
     DOOR = 18
     NON_WALK_GRASS = 19
+    SURFACE_MATERIAL_20 = 20
+    SURFACE_MATERIAL_21 = 21
+    SURFACE_MATERIAL_22 = 22
+    SURFACE_MATERIAL_23 = 23
+    SURFACE_MATERIAL_24 = 24
+    SURFACE_MATERIAL_25 = 25
+    SURFACE_MATERIAL_26 = 26
+    SURFACE_MATERIAL_27 = 27
+    SURFACE_MATERIAL_28 = 28
+    SURFACE_MATERIAL_29 = 29
     TRIGGER = 30
 
     def walkable(
