@@ -184,6 +184,12 @@ class GITInstance(ABC):
     ) -> Optional[ResRef]:
         ...
 
+    @abstractmethod
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        ...
+
     @abstractmethod
     def move(
             self,
@@ -249,6 +255,11 @@ class GITCamera(GITInstance):
     ) -> Optional[ResRef]:
         return None
 
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return None
+
     def classification(
             self
     ) -> str:
@@ -291,6 +302,11 @@ class GITCreature(GITInstance):
     ) -> Optional[ResRef]:
         return self.resref
 
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return ResourceType.UTC
+
     def classification(
             self
     ) -> str:
@@ -345,6 +361,11 @@ class GITDoor(GITInstance):
     ) -> Optional[ResRef]:
         return self.resref
 
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return ResourceType.UTD
+
     def classification(
             self
     ) -> str:
@@ -358,7 +379,9 @@ class GITEncounterSpawnPoint:
             y: float = 0.0,
             z: float = 0.0
     ):
-        super().__init__(x, y, z)
+        self.x = x
+        self.y = y
+        self.z = z
         self.orientation: float = 0.0
 
 
@@ -401,6 +424,11 @@ class GITEncounter(GITInstance):
     ) -> Optional[ResRef]:
         return self.resref
 
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return ResourceType.UTE
+
     def classification(
             self
     ) -> str:
@@ -444,6 +472,11 @@ class GITPlaceable(GITInstance):
     ) -> Optional[ResRef]:
         return self.resref
 
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return ResourceType.UTP
+
     def classification(
             self
     ) -> str:
@@ -480,6 +513,11 @@ class GITSound(GITInstance):
     ) -> None:
         raise ValueError("Sounds cannot be rotated.")
 
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return ResourceType.UTS
+
     def reference(
             self
     ) -> Optional[ResRef]:
@@ -526,7 +564,12 @@ class GITStore(GITInstance):
             self
     ) -> Optional[ResRef]:
         return self.resref
-
+    
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return ResourceType.UTM
+    
     def classification(
             self
     ) -> str:
@@ -575,6 +618,11 @@ class GITTrigger(GITInstance):
     ) -> Optional[ResRef]:
         return self.resref
 
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return ResourceType.UTT
+
     def classification(
             self
     ) -> str:
@@ -633,6 +681,11 @@ class GITWaypoint(GITInstance):
     ) -> Optional[ResRef]:
         return self.resref
 
+    def extension(
+            self
+    ) -> Optional[ResourceType]:
+        return ResourceType.UTW
+
     def classification(
             self
     ) -> str:
